@@ -199,8 +199,7 @@ class UpdateParametersAction(templates.ProcessTemplatesAction):
             # There has been an error validating we must reprocess the
             # templates with the saved working env
             plan_utils.put_env(swift, saved_env)
-            env = saved_env
-            processed_data = super(UpdateParametersAction, self).run(context)
+            self._process_custom_roles(context)
 
             err_msg = ("Error validating environment for plan %s: %s" % (
                 self.container, err))
@@ -394,7 +393,7 @@ class GenerateFencingParametersAction(base.TripleOAction):
             if "ports" in node:
                 # Not all Ironic drivers present a MAC address, so we only
                 # capture it if it's present
-                mac_addr = node['ports'][0]['address']
+                mac_addr = node['ports'][0]['address'].lower()
                 node_data["host_mac"] = mac_addr
 
                 # If the MAC isn't in the hostmap, this node hasn't been
