@@ -41,6 +41,7 @@ from tripleo_common.actions import ansible
 from tripleo_common.image.base import BaseImageManager
 from tripleo_common.image.exception import ImageNotFoundException
 from tripleo_common.image.exception import ImageUploaderException
+from tripleo_common.image import image_export
 
 
 LOG = logging.getLogger(__name__)
@@ -88,7 +89,7 @@ MEDIA_TYPES = (
     'application/vnd.docker.image.rootfs.diff.tar.gzip'
 )
 
-DEFAULT_UPLOADER = 'docker'
+DEFAULT_UPLOADER = 'python'
 
 
 def get_undercloud_registry():
@@ -193,6 +194,8 @@ class BaseImageUploader(object):
     mirrors = {}
     insecure_registries = set()
     secure_registries = set(SECURE_REGISTRIES)
+    export_registries = set()
+    push_registries = set()
 
     def __init__(self):
         self.upload_tasks = []
@@ -206,6 +209,8 @@ class BaseImageUploader(object):
         cls.secure_registries.clear()
         cls.secure_registries.update(SECURE_REGISTRIES)
         cls.mirrors.clear()
+        cls.export_registries.clear()
+        cls.push_registries.clear()
 
     def cleanup(self):
         pass
@@ -243,8 +248,12 @@ class BaseImageUploader(object):
             action = ansible.AnsiblePlaybookAction(
                 playbook=playbook,
                 work_dir=work_dir,
-                verbosity=3,
-                extra_env_variables=dict(os.environ)
+                verbosity=1,
+                extra_env_variables=dict(os.environ),
+                override_ansible_cfg=(
+                    "[defaults]\n"
+                    "stdout_callback=yaml\n"
+                )
             )
             result = action.run(None)
             log_path = result.get('log_path')
@@ -392,7 +401,7 @@ class BaseImageUploader(object):
         manifest_r = manifest_f.result()
         tags_r = tags_f.result()
 
-        if manifest_r.status_code == 404:
+        if manifest_r.status_code in (403, 404):
             raise ImageNotFoundException('Not found image: %s' %
                                          image_url.geturl())
         manifest_r.raise_for_status()
@@ -580,6 +589,12 @@ class BaseImageUploader(object):
                           source_layers, session):
         netloc = target_image_url.netloc
         name = target_image_url.path.split(':')[0][1:]
+        export = netloc in cls.export_registries
+        if export:
+            image_export.cross_repo_mount(
+                target_image_url, image_layers, source_layers)
+            return
+
         if netloc in cls.insecure_registries:
             scheme = 'http'
         else:
@@ -900,6 +915,8 @@ class PythonImageUploader(BaseImageUploader):
         target_session = self.authenticate(
             t.target_image_url)
 
+        self._detect_target_export(t.target_image_url, target_session)
+
         if t.modify_role:
             if self._image_exists(
                     t.target_image, target_session):
@@ -973,6 +990,34 @@ class PythonImageUploader(BaseImageUploader):
             self.image_layers.setdefault(layer, t.target_image_url)
         return to_cleanup
 
+    @classmethod
+    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
+        reraise=True,
+        retry=tenacity.retry_if_exception_type(
+            requests.exceptions.RequestException
+        ),
+        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
+        stop=tenacity.stop_after_attempt(5)
+    )
+    def _detect_target_export(cls, image_url, session):
+        if image_url.netloc in cls.export_registries:
+            return True
+        if image_url.netloc in cls.push_registries:
+            return False
+
+        # detect if the registry is push-capable by requesting an upload URL.
+        image, tag = cls._image_tag_from_url(image_url)
+        upload_req_url = cls._build_url(
+            image_url,
+            path=CALL_UPLOAD % {'image': image})
+        r = session.post(upload_req_url, timeout=30)
+        if r.status_code in (501, 403, 404, 405):
+            cls.export_registries.add(image_url.netloc)
+            return True
+        r.raise_for_status()
+        cls.push_registries.add(image_url.netloc)
+        return False
+
     @classmethod
     @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
         reraise=True,
@@ -993,7 +1038,7 @@ class PythonImageUploader(BaseImageUploader):
         )
         manifest_headers = {'Accept': MEDIA_MANIFEST_V2}
         r = session.get(url, headers=manifest_headers, timeout=30)
-        if r.status_code == 404:
+        if r.status_code in (403, 404):
             raise ImageNotFoundException('Not found image: %s' %
                                          url.geturl())
         r.raise_for_status()
@@ -1021,6 +1066,14 @@ class PythonImageUploader(BaseImageUploader):
         return r.headers['Location']
 
     @classmethod
+    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
+        reraise=True,
+        retry=tenacity.retry_if_exception_type(
+            requests.exceptions.RequestException
+        ),
+        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
+        stop=tenacity.stop_after_attempt(5)
+    )
     def _layer_stream_registry(cls, digest, source_url, calc_digest,
                                session):
         LOG.debug('Fetching layer: %s' % digest)
@@ -1143,6 +1196,7 @@ class PythonImageUploader(BaseImageUploader):
                                           manifest_str,
                                           config_str,
                                           target_session=None):
+
         manifest = json.loads(manifest_str)
         if config_str is not None:
             manifest['config']['size'] = len(config_str)
@@ -1156,6 +1210,16 @@ class PythonImageUploader(BaseImageUploader):
             else:
                 manifest_type = MEDIA_MANIFEST_V1
 
+        export = target_url.netloc in cls.export_registries
+        if export:
+            image_export.export_manifest_config(
+                target_url,
+                manifest_str,
+                manifest_type,
+                config_str
+            )
+            return
+
         if config_str is not None:
             config_digest = manifest['config']['digest']
             # Upload the config json as a blob
@@ -1219,7 +1283,8 @@ class PythonImageUploader(BaseImageUploader):
         cmd.append(pull_source)
         LOG.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE)
+        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                   universal_newlines=True)
 
         out, err = process.communicate()
         LOG.info(out)
@@ -1335,6 +1400,11 @@ class PythonImageUploader(BaseImageUploader):
         length = 0
         upload_resp = None
 
+        export = target_url.netloc in cls.export_registries
+        if export:
+            return image_export.export_stream(
+                target_url, layer, layer_stream)
+
         for chunk in layer_stream:
             if not chunk:
                 break
@@ -1507,7 +1577,8 @@ class PythonImageUploader(BaseImageUploader):
         cmd = ['podman', 'rmi', image_url.path]
         LOG.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE)
+        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                   universal_newlines=True)
 
         out, err = process.communicate()
         LOG.info(out)
