@@ -54,6 +54,10 @@ class TestImageUploadManager(base.TestCase):
         files.append('testfile')
         self.filelist = files
 
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._fetch_manifest')
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._copy_registry_to_registry')
     @mock.patch('tripleo_common.image.image_uploader.'
                 'BaseImageUploader.authenticate')
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -68,13 +72,13 @@ class TestImageUploadManager(base.TestCase):
                 return_value=False)
     @mock.patch('os.path.isfile', return_value=True)
     @mock.patch('fcntl.ioctl', side_effect=Exception)
-    @mock.patch('tripleo_common.image.image_uploader.Client')
     @mock.patch('tripleo_common.image.image_uploader.'
                 'get_undercloud_registry', return_value='192.0.2.0:8787')
-    def test_file_parsing(self, mock_gur, mockdocker, mockioctl, mockpath,
+    def test_file_parsing(self, mock_gur, mockioctl, mockpath,
                           mock_images_match, mock_is_insecure, mock_inspect,
-                          mock_auth):
+                          mock_auth, mock_copy, mock_manifest):
 
+        mock_manifest.return_value = '{"layers": []}'
         mock_inspect.return_value = {}
         manager = image_uploader.ImageUploadManager(self.filelist)
         parsed_data = manager.upload()
@@ -87,27 +91,6 @@ class TestImageUploadManager(base.TestCase):
                                     key=operator.itemgetter('imagename'))
         self.assertEqual(sorted_expected_data, sorted_parsed_data)
 
-        dockerc = mockdocker.return_value
-        dockerc.remove_image.assert_has_calls([
-            mock.call('192.0.2.0:8787/tripleomaster'
-                      '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleomaster'
-                      '/centos-binary-nova-compute:liberty'),
-            mock.call('docker.io/tripleomaster'
-                      '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleomaster'
-                      '/heat-docker-agents-centos:latest'),
-            mock.call('docker.io/tripleomaster'
-                      '/image-with-missing-tag:latest'),
-
-            mock.call('localhost:8787/tripleomaster'
-                      '/centos-binary-nova-compute:liberty'),
-            mock.call('localhost:8787/tripleomaster'
-                      '/heat-docker-agents-centos:latest'),
-            mock.call('localhost:8787/tripleomaster/'
-                      'image-with-missing-tag:latest'),
-        ])
-
     @mock.patch('netifaces.ifaddresses')
     @mock.patch('netifaces.interfaces')
     def test_get_undercloud_registry(self, mock_interfaces, mock_addresses):
@@ -799,8 +782,12 @@ class TestDockerImageUploader(base.TestCase):
         mock_ansible.assert_called_once_with(
             playbook=playbook,
             work_dir=mock.ANY,
-            verbosity=3,
-            extra_env_variables=mock.ANY
+            verbosity=1,
+            extra_env_variables=mock.ANY,
+            override_ansible_cfg=(
+                "[defaults]\n"
+                "stdout_callback=yaml\n"
+            )
         )
         self.dockermock.return_value.tag.assert_not_called()
         self.dockermock.return_value.push.assert_called_once_with(
@@ -1100,8 +1087,12 @@ class TestSkopeoImageUploader(base.TestCase):
         mock_ansible.assert_called_once_with(
             playbook=playbook,
             work_dir=mock.ANY,
-            verbosity=3,
-            extra_env_variables=mock.ANY
+            verbosity=1,
+            extra_env_variables=mock.ANY,
+            override_ansible_cfg=(
+                "[defaults]\n"
+                "stdout_callback=yaml\n"
+            )
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -2075,7 +2066,8 @@ class TestPythonImageUploader(base.TestCase):
             'podman',
             'rmi',
             '/t/nova-api:latest'],
-            env={}, stdout=-1
+            env={}, stdout=-1,
+            universal_newlines=True
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
