@@ -99,8 +99,14 @@ def process_environments_and_files(swift, env_paths):
     def _env_path_is_object(env_path):
         return env_path.startswith(swift.url)
 
+    # XXX this should belong in heatclient, but for the time being and backport
+    # purposes, let's do that here for now.
+    _cache = {}
+
     def _object_request(method, url, token=swift.token):
-        return object_request(method, url, token)
+        if url not in _cache:
+            _cache[url] = object_request(method, url, token)
+        return _cache[url]
 
     return template_utils.process_multiple_environments_and_files(
         env_paths=env_paths,
@@ -186,9 +192,12 @@ def apply_environments_order(capabilities, environments):
                         = environment.get('requires', [])
 
     # apply ordering rules
+    rest = []
     for e in environments:
         path = e.get('path', '')
         if path not in order_rules:
+            environments.remove(e)
+            rest.append(e)
             continue
         path_pos = environments.index(e)
         for requirement in order_rules[path]:
@@ -198,4 +207,4 @@ def apply_environments_order(capabilities, environments):
                     item = environments.pop(requirement_pos)
                     environments.insert(path_pos, item)
 
-    return environments
+    return environments + rest
